% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CNVmap.R
\name{CNV_type}
\alias{CNV_type}
\title{Identify CNV type based on profiles}
\usage{
CNV_type(candPeaks, myMap, nbObs, hypotheses, prof)
}
\arguments{
\item{candPeaks}{data frame: description of all peaks detected in the allele
frequency profiles, as returned by the function find_peaks}

\item{myMap}{data frame: genetic map as returned by the function load_data}

\item{nbObs}{vector of numeric: number of individuals assigned to each of the 
6 genotypic classes given in names}

\item{hypotheses}{list: description of all CNV hypotheses considered, as
returned by the function get_hypotheses}

\item{prof}{list: allele frequencies for each marker and each genotypic class, as 
returned by the function genome_profiles}
}
\value{
list:\cr
\itemize{
  \item $type character string: type of event (structural variant) identified: the different
  loci (duplicated regions) are separated by "_". Parental genotypes at each locus 
  are given as X/Y where X is the genotype of parent_1 and Y the genotype of parent_2
  \item $trueLoci data frame: each row is a locus (a copy of the CNV region).
  Columns are:\cr
  $hyp character string: type of event as defined above\cr
  $locus numeric: index of the locus (e.g. 1 or 2 for a 1:2 CNV)\cr
  $chr numeric: index of the chromosome (or linkage group)\cr
  $iStart numeric: index of the first marker of the region\cr
  $iStop numeric: index of the last marker of the region\cr
  $mrkStart character string: name of the first marker of the region\cr
  $mrkStop character string: name of the last marker of the region\cr
  $genStart numeric: genetic position of the first marker of the region\cr
  $genStop numeric: genetic position of the last marker of the region\cr
  \item $scoreHyps vector of logicals: each element is a type of event, 
  names are the event type as defined above, values are TRUE if the data 
  are compatible with the event considered, otherwise FALSE.
}
}
\description{
Compares the observed profile of allele frequencies with those 
expected under each of the hypotheses listed in the parameter "hypotheses"
}
