% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CNVmap.R
\name{CNVdetect}
\alias{CNVdetect}
\title{CNVdetect}
\usage{
CNVdetect(popName, mappingPanelType = "DH", parents = c("P1", "P2"),
  nbSelfingGenerationsRils = 6, nbIntermatingGenerations = 4,
  nuGamma = 3, maxPercentGenot = 90, quantThresHetMend = 70,
  quantThresMissMend = 70, minMafMend = 0.15,
  analyzeMarkersWithoutHetero = TRUE, quantThresHetCand = 93,
  quantThresMissCand = 95, minNbMrkPerTarget = 2,
  maxGenDistToFusePeaks = 10, winSizeToFitPeakShape = 40,
  minSlopePeak = -0.05, toleranceFreq = 0.05, minR2peak = 0.7,
  simulateProfiles = TRUE, plotCNVstrong = TRUE, plotCNVweak = TRUE,
  plotUnclassified = TRUE, plotSingleLocus = FALSE,
  customCandidateList = NULL, numberShufflesForPvalue = 100,
  printDistribTypesShuffles = TRUE, plotShuffles = FALSE, nbCpus = 1)
}
\arguments{
\item{popName}{character string: name of the data set to be analyzed. This 
name must be used as prefix for the data files}

\item{mappingPanelType}{character string: may be one of the following: "DH" for
doubled-haploids, "RIL" for recombinant inbred lines, or "IRIL" for intermated
recombinant inbred lines having undergone a number of random mating generations 
before selfing or sib-mating}

\item{parents}{vector of 2 character strings: vector of the names of the two
parents, as they will appear in the outputs}

\item{nbSelfingGenerationsRils}{numeric: number of generations of selfing
or sib-mating performed for recombinant inbred lines}

\item{nbIntermatingGenerations}{numeric: number of panmictic generations 
before selfing in the case of IRILs}

\item{nuGamma}{numeric: strength of crossover interference, expressed
as the parameter 'nu' of the Gamma model. Used to incorporate interference
in simulations of segregation data. nu=1 means no interference, nu>1 means
positive crossover interference}

\item{maxPercentGenot}{numeric: maximum frequency (in percentage) of any
genotype (A, B, or H) allowed for an individual to be kept for the analyses}

\item{quantThresHetMend}{numeric: threshold for the maximum quantile of 
heterozygous calls for a marker to be used in allele frequency analyses}

\item{quantThresMissMend}{numeric: threshold for the maximum quantile of 
missing data calls for a marker to be used in allele frequency analyses}

\item{minMafMend}{numeric: minimum value of Minor Allele Frequency for
a marker to be used in allele frequency analyses}

\item{analyzeMarkersWithoutHetero}{logical: if TRUE, markers with anomalously 
high rates of missing data will also be considered as candidates
for being associated to CNV events (otherwise only those with anomalously 
high rates of heterozygote calls will be candidates)}

\item{quantThresHetCand}{numeric: threshold for the maximum quantile of 
heterozygous calls for a marker to be considered as candidates
for being associated to CNV events}

\item{quantThresMissCand}{numeric: threshold for the maximum quantile of 
missing data for a marker to be considered as candidates for being
associated to CNV events}

\item{minNbMrkPerTarget}{numeric: minimum number of markers required
within a peak for the peak to be considered valid}

\item{maxGenDistToFusePeaks}{numeric: maximum genetic distance
in centiMorgans below which two detected peaks will be fused}

\item{winSizeToFitPeakShape}{numeric: genetic distance in
centiMorgans on each side of a peak, where linear regression
analysis will be performed to check the shape of the peak}

\item{minSlopePeak}{numeric: minimum slope of the regression line
fitted on either side of a putative peak}

\item{toleranceFreq}{numeric: maximum allele frequency considered
as zero for peak detection (or symmetrically close to one)}

\item{minR2peak}{numeric: minimum value of the regression R-square
on either side of a peak for valid detection}

\item{simulateProfiles}{logical: if TRUE, for each candidate marker 
which leads to the identification of a CNV event, segregation data
will be simulated under the hypothesis of the identified type of
CNV, and used to plot allele frequency profiles which can be compared
to the ones obtained with the experimental data. Such simulation
takes some additional time, but provides an important means to assess
a posteriori the quality of the automatic identification of the CNV
type performed by the software}

\item{plotCNVstrong}{logical: if TRUE, generates plots for marker candidates
which lead to the identification of a CNV with strong signature (that is
based on at least one peak of non-missing data per locus). Useful 
to visually assess the validity of the automatic identification 
of CNVs, and check for possible false positives}

\item{plotCNVweak}{logical: if TRUE, generates plots for marker candidates
which lead to the identification of a CNV with weak signature (that is 
based on only one peak of missing data). This may increase the size of
output files without producing new true positives}

\item{plotUnclassified}{logical: if TRUE, generates plots for events
in which peaks have been detected, but did not match any of the
CNV signatures considered in the software. Such plots may be used 
to estimate by eye the level of false negatives, or to discover
new types of events which were not considered in the software but
may be of interest}

\item{plotSingleLocus}{logical: if TRUE, plots allele frequency profiles
for candidate markers for which only the peaks corresponding to the
expected signature of a single locus were detected. May be useful to 
check for possible false negatives but may produce huge files}

\item{customCandidateList}{vector of character strings. List of names
of candidate markers to be analyzed. If NULL, then all candidates will 
be kept. If the list contains markers that are not candidates, they
will not be analyzed.}

\item{numberShufflesForPvalue}{numeric: number of profiles simulated under
the hypothesis H0="single-locus" to calculate a p-value. Caution: may be long...
If equal to zero (default), then no P-value is calculated.}

\item{printDistribTypesShuffles}{logical: if TRUE outputs distribution
of CNV types from all shuffled data generated to calculate P-values}

\item{plotShuffles}{logical: if TRUE generates and saves profile plots 
for all shuffled data generated to calculate P-values. Caution: this will
generate one file for each candidate marker!}

\item{nbCpus}{numeric: number of CPUs used for parallelization of the
shuffles to compute the p-value for H0="single-locus". If nbCpu=1
then no parallelization, otherwise requires installing the package 
'doParallel' which requires 'foreach' and 'iterators'}
}
\description{
Analyzes a genetic segregation data set to detect signatures
of copy-number variants (CNVs). Characterizes the type of event and maps the new
loci discovered.\cr
This function requires the following data files in the working directory:\cr
(1) File <popName>.map tab-separated text file without headers, with\cr
 - First column character string: marker names. \cr
 - Second column character string: chromosome name (numeric or alphanumeric).\cr
 - Third column numeric: genetic map position in centiMorgans.\cr
(2) File <popName>.seg tab-separated text file without headers containing:\cr
 - A first line with all names of individuals in the population,\cr
 - Then one line per marker with marker name as first column and genotype 
   calls ("A", "B", "H", or "-") of each individual of the population in 
   subsequent columns, with the order of individuals corresponding to that
   of the first line\cr
Alternatively, segregation data may be provided as MapMaker files (.raw file)
or as SNP genotype files (.snp file). See details of these formats
in function load_data()
}
\examples{
CNVdetect(popName="GABI")
}
