% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CNVmap.R
\name{find_peaks}
\alias{find_peaks}
\title{Detect and locate peaks of allele frequency}
\usage{
find_peaks(prof, myMap, minNbMrkPerTarget, maxGenDistToFusePeaks,
  freqThresh, minSlopePeak, minR2peak, winSizeToFitPeakShape,
  PLOT_REGRESSIONS = FALSE)
}
\arguments{
\item{prof}{list: (as returned by function genome_profiles)\cr}

\item{myMap}{data frame: each row is a marker, columns are:
\itemize{
    \item $snpName character string: name of the marker
    \item $chr character string or numeric: chromosome (linkage group)
    \item $genPos numeric: genetic position in cM of the marker
}}

\item{minNbMrkPerTarget}{numeric: minimum number of markers within one 
target chromosome}

\item{maxGenDistToFusePeaks}{numeric: genetic distance in centiMorgans
below which two detected peaks will be considered as a single wide peak}

\item{freqThresh}{numeric: minimum allele frequency required to detect a peak}

\item{minSlopePeak}{numeric: minimum slope of the regression line on either 
side of the peak for the peak to be valid}

\item{winSizeToFitPeakShape}{numeric: minimum genetic distance in centiMorgans 
on each side of the peak, where allele frequencies will be fir by a regression 
line}
}
\value{
list:\cr
$candPeaks: data frame (each row is a candidate peak), with columns:\cr
\itemize{
    \item $class numeric: index of the genotypic class (1:AAA. 2:AHA, 3:A-A, 
    4:BBB, 5:BHB, 6:B-B)
    \item $phase character: "A" for peak pointing to high frequency of allele 
    "A" (upwards), or "B" for peak pointing to high frequency of allele "B"
    (downwards)
    \item $chr character string or numeric: name of the chromosome where the 
    peak was detected
    \item $iStart numeric: index of the first marker of the peak
    \item $iStop numeric: index of the last marker of the peak
    \item $mrkStart character string: name of the first marker of the peak
    \item $mrkStop character string: name of the last marker of the peak
    \item $genStart numeric: genetic position in centiMorgan of the first 
    marker of the peak
    \item $genStop numeric: genetic position in centiMorgan of the last 
    marker of the peak
    \item $leftSlope  numeric: slope of the regression line on left side of the peak
    \item $rightSlope  numeric: slope of the regression line on right side of the peak
    \item $R2  numeric: R-squared of the linear regression on the peak side for 
    which the value is the smallest
    \item $leftPeakPos  numeric: smallest estimation of peak position
    \item $rightPeakPos  numeric: largest estimation of peak position
}\cr
$smProf list: allele frequenci profiles for each genotypic class as generated 
by the funciton genome_profile, but smoothed and filtered for outliers using splines. \cr
}
\description{
Detects peaks having sufficient width and slopes on 
each side. Merges peaks too close to each other.\cr
Allele frequency profiles corresponding to each possible genotypic class 
will be analyzed one after each other for peaks pointing Up or Down.
}
