% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CNVmap.R
\name{match_hypotheses}
\alias{match_hypotheses}
\title{Match hypothesis}
\usage{
match_hypotheses(candPeaks, hyp, myMap, nbObs, prof)
}
\arguments{
\item{candPeaks}{data frame (each row is a candidate peak), with columns:
\itemize{
    \item $class numeric: index of the genotypic class (1:AAA. 2:AHA, 3:A-A, 
    4:BBB, 5:BHB, 6:B-B)
    \item $phase character: "A" for peak pointing to high frequency of allele 
    "A" (upwards), or "B" for peak pointing to high frequency of allele "B"
    (downwards)
    \item $chr character string or numeric: name of the chromosome where the 
    peak was detected
    \item $iStart numeric: index of the first marker of the peak
    \item $iStop numeric: index of the last marker of the peak
    \item $mrkStart character string: name of the first marker of the peak
    \item $mrkStop character string: name of the last marker of the peak
    \item $genStart numeric: genetic position in centiMorgan of the first 
    marker of the peak
    \item $genStop numeric: genetic position in centiMorgan of the last 
    marker of the peak
    \item $slope  numeric: slope of the regression line on both sides of the peak
}}

\item{hyp}{vector of character strings: one element for each locus, contains 
the specification of the peak patterns expected for a given scenario of 
structural variant. For each locus, this pattern is encoded as a string 
of 6 characters, each of them corresponding to one of the genotypic classes (1:AAA,
2:AHA, 3:A-A, 4:BBB, 5:BHB, 6:B-B). For each of these 6 characters, "A" indicates
a complete peak pointing upwards to 100 percent frequency of allele "A", "B" a complete 
peak pointing downwards to 100 percent of "B", "E" a flat line around 50 percent, (equal frequencies 
for "A" and "B" alleles, "C" a partial peak pointing upwards to 0.5 < f(A) < 1, and "D" 
a partial peak pointing downwards to 0.5 < f(B) < 1}

\item{myMap}{data frame: each row is a marker, columns are:
\itemize{
   \item $snpName: name of the marker
   \item $chr: chromosome (linkage group)
   \item $genPos: genetic position in cM of the marker
}}
}
\value{
loci data frame: each row is a locus, columns are:\cr
\itemize{
   \item $locus numeric: index of the locus
   \item $chr numeric: chromosome (linkage group)
   \item $iStart numeric: index of the first marker within the region
   \item $iStop numeric: index of the last marker of the region
   \item $mrkStart character string: name of the first marker of the region
   \item $mrkStop character string: name of the last marker of the region
   \item $genPosInf numeric: genetic position (in centiMorgans) of the first 
   marker of the region
   \item $genPosMean numeric: middle genetic position (in centiMorgans) of the region
   \item $genPosSup numeric: genetic position (in centiMorgans) of the last 
   marker of the region
}
}
\description{
Determines if a given type of structural variant is compatible with the 
list of peaks detected in the allele frequency profiles
}
